@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11979 2020-03-18 04:52:03Z Trista $
+# $Id: models.py 12169 2020-05-06 06:56:44Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-03-18 12:52:03 +0800 (週三, 18 三月 2020) $
-# $Revision: 11979 $
+# $Date: 2020-05-06 14:56:44 +0800 (週三, 06 五月 2020) $
+# $Revision: 12169 $
 
 from functools import wraps
 from django import forms
@@ -204,6 +204,17 @@ class CallToActionModel(CMSPlugin):
         choices=_settings.CALL_TO_ACTION_TEMPLATES,
         default=_settings.CALL_TO_ACTION_DEFAULT_TEMPLATE,
     )
+    fileName = models.CharField(
+        _('File Name'), max_length=150, blank=True,
+    )
+    
+    @property
+    def isArticlePDF(self):
+        if self.linkUrl or self.targetFile:
+            return False
+        else:
+            return True
+            
 
 
 class CallToActionStatistics(models.Model):
