@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11243 2018-10-05 09:20:04Z Lavender $
+# $Id: cms_plugins.py 12225 2020-05-15 10:17:05Z Andy $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-10-05 17:20:04 +0800 (週五, 05 十月 2018) $
-# $Revision: 11243 $
+# $Author: Andy $ (last)
+# $Date: 2020-05-15 18:17:05 +0800 (週五, 15 五月 2020) $
+# $Revision: 12225 $
 
 from django.db.models import Count
 from django.template.loader import select_template
@@ -41,7 +41,7 @@ else:
 
 class FeaturedPlugin(CMSPluginBase):
     model = OscarFeatured
-    module = "Zephyrus Oscar"
+    module = "Shop"
     name = "Featured Products"
     render_template = settings.ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE
     form = OscarFeaturedForm
@@ -103,7 +103,7 @@ class FeaturedPlugin(CMSPluginBase):
 
 class LatestPlugin(CMSPluginBase):
     model = OscarLatest
-    module = "Zephyrus Oscar"
+    module = "Shop"
     name = "Latest Products"
     render_template = settings.ZEPHYRUS_OSCAR_LATEST_DEFAULT_TEMPLATE
     form = OscarLatestForm
@@ -163,7 +163,7 @@ class LatestPlugin(CMSPluginBase):
 
 class OfferPlugin(CMSPluginBase):
     model = OscarOffer
-    module = "Zephyrus Oscar"
+    module = "Shop"
     name = "Offer Products"
     render_template = settings.ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE
     
